FederSite — MSUMastro toolbox 0.1 documentation

# FederSite

class `msumastro.header_processing.feder.` `FederSite`

  Bases: `astropysics.obstools.Site`

  The Feder Observatory site.

  An astropysics site with the observatory location and name pre-set to:

  > - lat = 46.86678 degrees North
  > - long = -96.453278 degrees East
  > - alt = 311.8 meters
  > - name = Feder Observatory

  Methods Summary

  `localSiderialTime`([seconds_decimal]) |

  Methods Documentation

  `localSiderialTime`(seconds_decimal=None, *arg, **kwd)